# Python Docstring & Pytest Example


## Doctest

### Qu'est-ce que Doctest ?
**Doctest** est un module intégré à Python qui vous permet d'écrire des tests directement dans les docstrings de vos fonctions. Il exécute les exemples de code contenus dans les docstrings et vérifie que les résultats obtenus correspondent aux résultats attendus.

### Exemple de Doctest dans une docstring

Voici un exemple de fonction avec un test inclus dans la docstring :

```python
def addition(a, b):
    """
    Additionne deux nombres.

    Paramètres:
    a (int, float): Le premier nombre à additionner.
    b (int, float): Le deuxième nombre à additionner.

    Retourne:
    int, float: Le résultat de l'addition.

    Exemples:
    >>> addition(2, 3)
    5
    >>> addition(-1, 1)
    0
    >>> addition(0, 0)
    0
    """
    return a + b
```

### Lancer Doctest

Vous pouvez exécuter les tests inclus dans les docstrings en utilisant la commande suivante :

```bash
python -m doctest -v <nom_du_fichier>.py
```

- **-m doctest** : Exécute le module Doctest.
- **-v** : Mode verbeux pour afficher les détails de chaque test.

Par exemple

```bash
python -m doctest -v main.py
```

---

## Pytest

### Qu'est-ce que Pytest ?
**Pytest** est un cadre de test Python puissant et flexible qui permet d'écrire des tests unitaires. Contrairement à Doctest, Pytest ne repose pas sur les docstrings mais sur des fichiers de tests séparés. Il offre de nombreuses fonctionnalités comme les tests paramétrés, les fixtures, et une gestion plus robuste des erreurs.

### Exemple de test avec Pytest

Voici un exemple de test Pytest pour la fonction `addition` :

```python
def test_addition():
    assert addition(2, 3) == 5
    assert addition(-1, 1) == 0
    assert addition(0, 0) == 0
    assert addition(100, -50) == 50
```

Le test est placé dans un fichier séparé, typiquement nommé `test_<nom_du_fichier>.py`, comme `test_main.py`.

### Lancer Pytest

Pour exécuter vos tests Pytest, vous pouvez utiliser la commande suivante :

```bash
pytest
```

Pour le mode verbose sur un fichier donné:
```bash
ou pour le mode verbose
pytest -v tests_for_pytest.py
```

## Installation
```bash
pip install –user pytest 
(--user est nécessaire en salle info car vous n’avez pas les droits d’admin)
```
