"""
Écrivez des tests pytest pour la fonction french_scrabble_score

Idée de tests pour french_scrabble_score

Test de score de base : Vérifiez que la fonction calcule correctement le score pour des mots simples.
Test de mot invalide : Assurez-vous que la fonction retourne -1 pour un mot qui n'est pas dans le dictionnaire.
Test de casse : Vérifiez que la fonction fonctionne correctement indépendamment de la casse du mot.
Test de caractères spéciaux : gérer les caractères spéciaux dans les mots.
Test de mot vide : Vérifiez le comportement de la fonction avec une chaîne vide.
Test de mots longs : Assurez-vous que la fonction calcule correctement le score pour des mots longs.

"""
def load_dic(path):
    """
    Charge une liste de mots à partir d'un fichier spécifié.

    Paramètres :
    - path (str) : Le chemin vers le fichier contenant la liste de mots, un par ligne.

    Retourne :
    - list : Une liste de mots extraits du fichier.

    Notes :
    - La fonction suppose que l'encodage du fichier est UTF-8.
    - Elle suppose également que chaque mot est sur une ligne séparée dans le fichier.

    Exemple :
    >>> load_dic("data/sample.txt")
    ['aalenien', 'aalenienne', 'aaleniennes']
    """

    lst = []
    with open(path, "r", encoding="UTF-8") as f:
        for row in f:
            print(row)
            lst.append(row.strip().lower())
            break
    return lst


def french_scrabble_score(word):
    # Valeurs des points pour chaque lettre dans le Scrabble français
    letter_values = {
        'a': 1, 'e': 1, 'i': 1, 'o': 1, 'u': 1, 'l': 1, 'n': 1, 'r': 1, 's': 1,
        't': 1,
        'd': 2, 'g': 2, 'm': 2,
        'b': 3, 'c': 3, 'p': 3,
        'f': 4, 'h': 4, 'v': 4,
        'j': 8, 'q': 8,
        'k': 10, 'w': 10, 'x': 10, 'y': 10,
        'z': 10
    }
    dico = load_dic("data/dico.txt")
    # Vérifie si le mot est dans le dictionnaire
    if word not in dico:
        return -1

    # Vérifie si le mot contient des accents
    for char in word:
        if char not in letter_values:
            raise ValueError(
                f"La lettre '{char}' n'est pas gérée par la fonction.")

    # Calcule le score
    score = 0
    # Convertit le mot en minuscules pour assurer la correspondance
    for letter in word.lower():
        score += letter_values.get(letter, 0)

    return score