import re


def clean_view_count(view: str) -> int:

    pattern = r"""
        (?P<number>     # Named group 'number': Captures the numeric part (integer or decimal)
            \d+         # One or more digits (the integer part)
            (?:         # Non-capturing group for the optional decimal part
                \.\d+   # A dot followed by one or more digits (the decimal part)
            )?          # The decimal part is optional
        )
        (?P<unit>       # Named group 'unit': Captures the optional unit ('K', 'M', 'B')
            [KMB]?      # Matches either 'K' for thousand, 'M' for million, 'B' for billion, or nothing
        )
    """
    pattern = r"(?P<number>\d+(?:\.\d+)?)(?P<unit>[KMB]?)"
    dic_unit = {"B": 1_000_000_000, "M": 1_000_000, "K": 1_000, "": 1}

    match = re.match(pattern, view)
    if not match:
        return -1

    num = float(match.group('number'))
    unit = match.group('unit')

    return int(num * dic_unit[unit])